@@ -169,6 +169,246 @@ size_t Phreeqc::list_components(std::list<std::string> &list_c)
 	}
 	return(list_c.size());
 }
+size_t Phreeqc::list_EquilibriumPhases(std::list<std::string> &list_pp)
+/*
+*	 Find all elements in any class definition
+*/
+{
+	std::set<std::string> accumulator;
+	// pure phases
+	{
+		std::map<int, cxxPPassemblage>::const_iterator cit = Rxn_pp_assemblage_map.begin();
+		for (; cit != Rxn_pp_assemblage_map.end(); cit++)
+		{
+			cxxPPassemblage entity = cit->second;
+			std::set<std::string> pp = entity.GetPhases(this);
+			std::set<std::string>::iterator ppit = pp.begin();
+			for (; ppit != pp.end(); ppit++)
+			{ 
+				accumulator.insert(*ppit);
+			}
+		}
+	}
+	list_pp.clear();
+	std::set<std::string>::iterator it = accumulator.begin();
+	for (; it != accumulator.end(); it++)
+	{
+		list_pp.insert(list_pp.end(),*it);
+	}
+	return(list_pp.size());
+}
+size_t Phreeqc::list_GasComponents(std::list<std::string> &list_gc)
+/*
+*	 Find all elements in any class definition
+*/
+{
+	std::set<std::string> accumulator;
+	// pure phases
+	{
+		std::map<int, cxxGasPhase>::const_iterator cit = Rxn_gas_phase_map.begin();
+		for (; cit != Rxn_gas_phase_map.end(); cit++)
+		{
+			cxxGasPhase entity = cit->second;
+			std::vector<cxxGasComp> &gc = entity.Get_gas_comps();
+			for (size_t i = 0; i < gc.size(); i++)
+			{
+				int j;
+				phase * p = phase_bsearch(gc[i].Get_phase_name().c_str(), &j, 0);
+				accumulator.insert(p->name);
+			}
+		}
+	}
+	list_gc.clear();
+	std::set<std::string>::iterator it = accumulator.begin();
+	for (; it != accumulator.end(); it++)
+	{
+		list_gc.insert(list_gc.end(), *it);
+	}
+	return(list_gc.size());
+}
+size_t Phreeqc::list_KineticReactions(std::list<std::string> &list_kr)
+/*
+*	 Find all kinetic reactions
+*/
+{
+	std::set<std::string> accumulator;
+	// Kinetics
+	{
+		std::map<int, cxxKinetics>::const_iterator cit = Rxn_kinetics_map.begin();
+		for (; cit != Rxn_kinetics_map.end(); cit++)
+		{
+			cxxKinetics entity = cit->second;
+			for (size_t i = 0; i < entity.Get_kinetics_comps().size(); i++)
+			{
+				std::string ratename = entity.Get_kinetics_comps()[i].Get_rate_name();
+				int j;
+				rate *r = rate_search(ratename.c_str(), &j);
+				if (r != NULL)
+				{
+					accumulator.insert(r->name);
+				}
+			}
+		}
+	}
+	list_kr.clear();
+	std::set<std::string>::iterator it = accumulator.begin();
+	for (; it != accumulator.end(); it++)
+	{
+		list_kr.insert(list_kr.end(), *it);
+	}
+	return(list_kr.size());
+}
+size_t Phreeqc::list_SolidSolutions(std::list<std::string> &list_comps, std::list<std::string> &list_names)
+/*
+*	 Find all elements in any class definition
+*/
+{
+	std::vector< std::set<std::string> > ss_sets;
+	std::vector<std::string> ss_names;
+	// solid solutions
+	std::map<int, cxxSSassemblage>::const_iterator cit = Rxn_ss_assemblage_map.begin();
+	// Fill vectors, ss names and related set of component names
+	for (; cit != Rxn_ss_assemblage_map.end(); cit++)
+	{
+		cxxSSassemblage entity = cit->second;
+		std::map<std::string, cxxSS> &SSs = entity.Get_SSs();
+		std::map<std::string, cxxSS>::iterator ssit = SSs.begin();
+		for (; ssit != SSs.end(); ssit++)
+		{
+			std::string ssname = ssit->second.Get_name();
+			std::set<std::string> accumulator_phases;
+			for (int i = 0; i < ssit->second.Get_ss_comps().size(); i++)
+			{
+				std::string pname = ssit->second.Get_ss_comps()[i].Get_name();
+				int j;
+				phase * p = phase_bsearch(pname.c_str(), &j, 0);
+				accumulator_phases.insert(p->name);
+			}
+			ss_names.push_back(ssname);
+			ss_sets.push_back(accumulator_phases);
+		}
+	}
+	// need to merge into exclusive sets of solid solution components
+	bool repeat = true;
+	while (repeat)
+	{
+		repeat = false;
+		for (int i = 0; i < (int) ss_sets.size() - 1; i++)
+		{
+			for (int j = i + 1; j < (int) ss_sets.size(); j++)
+			{
+				// locate any common component
+				std::set<std::string>::iterator it = ss_sets[j].begin();
+				for (; it != ss_sets[j].end(); it++)
+				{
+					if (ss_sets[i].find(*it) != ss_sets[i].end())
+					{
+						repeat = true;
+						break;
+					}
+				}
+				// merge sets and clear second set
+				if (repeat)
+				{
+					for (it = ss_sets[j].begin(); it != ss_sets[j].end(); it++)
+					{
+						ss_sets[i].insert(*it);
+					}
+					ss_sets[j].clear();
+					break;
+				}
+			}
+			if (repeat) break;
+		}
+	}
+	list_comps.clear();
+	list_names.clear();
+	// Write lists
+	for (size_t i = 0; i < ss_sets.size(); i++)
+	{
+		std::set<std::string>::iterator it = ss_sets[i].begin();
+		for (; it != ss_sets[i].end(); it++)
+		{
+			list_names.push_back(ss_names[i]);
+			list_comps.push_back(*it);
+		}
+	}
+	return(list_comps.size());
+}
+size_t Phreeqc::list_Surfaces(std::list<std::string> &list_surftype, std::list<std::string> &list_surfname)
+/*
+*	 Find all surface types and surfaces
+*/
+{
+	std::set<std::pair<std::string,std::string> > accumulator;
+	// Surfaces
+	{
+		std::map<int, cxxSurface>::const_iterator cit = Rxn_surface_map.begin();
+		for (; cit != Rxn_surface_map.end(); cit++)
+		{
+			cxxSurface entity = cit->second;
+			std::vector<cxxSurfaceComp> &scomps = entity.Get_surface_comps();
+			std::vector<cxxSurfaceCharge> &scharges = entity.Get_surface_charges();
+			for (size_t i = 0; i < scomps.size(); i++)
+			{
+				std::pair<std::string, std::string> p(scomps[i].Get_master_element(), scomps[i].Get_charge_name());
+				accumulator.insert(p);
+			}
+		}
+	}
+	list_surftype.clear();
+	list_surfname.clear();
+	std::set<std::pair<std::string, std::string> >::iterator it = accumulator.begin();
+	for (; it != accumulator.end(); it++)
+	{
+		list_surftype.push_back(it->first);
+		list_surfname.push_back(it->second);
+	}
+	return(list_surfname.size());
+}
+size_t Phreeqc::list_Exchangers(std::list<std::string> &list_exname)
+/*
+*	 Find all exchangers
+*/
+{
+	std::set<std::string> accumulator;
+	// Exchangers
+	std::map<int, cxxExchange>::const_iterator cit = Rxn_exchange_map.begin();
+	for (; cit != Rxn_exchange_map.end(); cit++)
+	{
+		cxxExchange entity = cit->second;
+		std::vector<cxxExchComp> &ecomps = entity.Get_exchange_comps();
+		for (size_t i = 0; i < ecomps.size(); i++)
+		{
+			std::string exname = "";
+			cxxNameDouble nd = ecomps[i].Get_totals();
+			cxxNameDouble::iterator it = nd.begin();
+			for (; it != nd.end(); it++)
+			{
+				struct master *m = master_bsearch(it->first.c_str());
+				if (m != NULL)
+				{
+					if (m->type == EX)
+					{
+						exname = it->first;
+						break;
+					}
+				}
+			}
+			if (exname != "")
+			{
+				accumulator.insert(exname);
+			}
+		}
+	}
+	list_exname.clear();
+	std::set< std::string>::iterator it = accumulator.begin();
+	for (; it != accumulator.end(); it++)
+	{
+		list_exname.push_back(*it);
+	}
+	return(list_exname.size());
+}
 Phreeqc::Phreeqc(PHRQ_io *io)
 {
 	// phrq_io
@@ -196,7 +436,9 @@ void Phreeqc::init(void)
 	current_pa                      = NAN;
 	current_mu                      = NAN;
 	mu_terms_in_logk                = true;
-
+	current_A                       = 0.0;
+	current_x                       = 0.0;
+	fix_current                     = 0.0;
 	/* ----------------------------------------------------------------------
 	*   STRUCTURES
 	* ---------------------------------------------------------------------- */
@@ -211,6 +453,7 @@ void Phreeqc::init(void)
 	last_model.count_kinetics       = -1;
 	last_model.kinetics             = NULL;
 	last_model.count_gas_phase      = -1;
+	last_model.gas_phase_type       = cxxGasPhase::GP_UNKNOWN;
 	last_model.gas_phase            = NULL;
 	last_model.count_ss_assemblage  = -1;
 	last_model.ss_assemblage        = NULL;
@@ -413,6 +656,7 @@ void Phreeqc::init(void)
 	tk_x                    = 0;
 	patm_x                  = 1;
 	last_patm_x             = 1;
+	potV_x                  = 0;
 	numerical_fixed_volume  = false;
 	force_numerical_fixed_volume = false;
 	//switch_numerical        = false;
@@ -443,6 +687,7 @@ void Phreeqc::init(void)
 	*   Transport data
 	*---------------------------------------------------------------------- */
 	count_cells              = 1;
+	cell_data_max_cells      = count_cells;
 	count_shifts             = 1;
 	ishift                   = 1;
 	bcon_first = bcon_last   = 3;
@@ -467,6 +712,7 @@ void Phreeqc::init(void)
 	multi_Dflag              = FALSE;
 	interlayer_Dflag         = FALSE;
 	default_Dw               = 0;
+	correct_Dw               = 0;
 	multi_Dpor               = 0;
 	interlayer_Dpor          = 0.1;
 	multi_Dpor_lim           = 0;
@@ -474,6 +720,7 @@ void Phreeqc::init(void)
 	multi_Dn                 = 0;
 	interlayer_tortf         = 100.0;
 	cell_no                  = 0;
+	fix_current              = 0.0;
 	/*----------------------------------------------------------------------
 	*   Advection data
 	*---------------------------------------------------------------------- */
@@ -689,7 +936,7 @@ void Phreeqc::init(void)
 	stop_program            = FALSE;
 	incremental_reactions   = FALSE;
 	count_strings           = 0;
-	array					= NULL;
+	my_array					= NULL;
 	delta					= NULL;
 	residual				= NULL;
 	input_error             = 0;
@@ -699,6 +946,7 @@ void Phreeqc::init(void)
 	iterations              = 0;
 	gamma_iterations        = 0;
 	run_reactions_iterations= 0;
+	overall_iterations      = 0;
 	max_line				= MAX_LINE;
 	line                    = NULL;
 	line_save				= NULL;
@@ -706,6 +954,8 @@ void Phreeqc::init(void)
 	debug_model             = FALSE;
 	debug_prep              = FALSE;
 	debug_set               = FALSE;
+	debug_mass_action       = FALSE;
+	debug_mass_balance      = FALSE;
 	debug_diffuse_layer     = FALSE;
 	debug_inverse           = FALSE;
 #ifdef USE_LONG_DOUBLE
@@ -719,6 +969,9 @@ void Phreeqc::init(void)
 #ifdef USE_LONG_DOUBLE
 	/* from float.h, sets tolerance for cl1 routine */
 	ineq_tol                = pow((long double) 10, (long double) -LDBL_DIG);
+#elif NPP
+// appt:
+	ineq_tol                = pow((double) 10, (double) -DBL_DIG + 2);
 #else
 	ineq_tol                = pow((double) 10, (double) -DBL_DIG);
 #endif
@@ -795,6 +1048,7 @@ void Phreeqc::init(void)
 	user_database			= NULL;
 	//have_punch_name			= FALSE;
 	print_density		    = 0;
+	print_viscosity		    = 0;
 	zeros                   = NULL;	
 	zeros_max			    = 1;
 	cell_pore_volume	    = 0;
@@ -807,6 +1061,8 @@ void Phreeqc::init(void)
 	sys_tot                 = 0;
 
 	V_solutes               = 0.0;
+	viscos                  = 0.0;
+	viscos_0                = 0.0;
 	rho_0                   = 0;
 	kappa_0                 = 0.0;
 	p_sat                   = 0.0;
@@ -989,7 +1245,11 @@ void Phreeqc::init(void)
 	/* phrq_io_output.cpp ------------------------------- */
 	forward_output_to_log   = 0;
 	/* phreeqc_files.cpp ------------------------------- */
-		default_data_base       = string_duplicate("phreeqc.dat");
+#ifdef NPP
+	default_data_base = string_duplicate("c:\\phreeqc\\database\\phreeqc.dat");
+#else
+	default_data_base = string_duplicate("phreeqc.dat");
+#endif
 #ifdef PHREEQ98
 	int outputlinenr;
 	char *LogFileNameC;
@@ -1018,6 +1278,7 @@ void Phreeqc::init(void)
 	OTEMP					= -100.;
 	OPRESS					= -100.;
 	A0                      = 0;	
+	aphi                    = NULL;
 	spec                    = NULL;
 	cations                 = NULL;
 	anions                  = NULL;
@@ -1348,6 +1609,7 @@ Phreeqc::InternalCopy(const Phreeqc *pSrc)
 	*   Transport data
 	*---------------------------------------------------------------------- */
 	count_cells              = pSrc->count_cells;
+	cell_data_max_cells      = pSrc->cell_data_max_cells;
 	count_shifts             = pSrc->count_shifts;
 	ishift                   = pSrc->ishift;
 	bcon_first				 = pSrc->bcon_first;
@@ -1371,9 +1633,9 @@ Phreeqc::InternalCopy(const Phreeqc *pSrc)
 	if (count_cells > 0)
 	{
 		cell_data = (struct cell_data *) free_check_null(cell_data);
-		cell_data = (struct cell_data *) PHRQ_malloc((size_t) (count_cells * sizeof(struct cell_data)));
+		cell_data = (struct cell_data *) PHRQ_malloc((size_t) ((count_cells + 2) * sizeof(struct cell_data)));
 		if (cell_data == NULL) malloc_error();
-		memcpy(cell_data, pSrc->cell_data, ((size_t) (count_cells * sizeof(struct cell_data))));
+		memcpy(cell_data, pSrc->cell_data, ((size_t) ((count_cells + 2) * sizeof(struct cell_data))));
 	}
 	old_cells = pSrc->old_cells;
 	max_cells = pSrc->max_cells;
@@ -1388,6 +1650,7 @@ Phreeqc::InternalCopy(const Phreeqc *pSrc)
 	multi_Dn                 = pSrc->multi_Dn;
 	interlayer_tortf         = pSrc->interlayer_tortf;
 	cell_no                  = pSrc->cell_no;
+	fix_current              = pSrc->fix_current;
 	/*----------------------------------------------------------------------
 	*   Advection data
 	*---------------------------------------------------------------------- */
@@ -1902,7 +2165,7 @@ Phreeqc::InternalCopy(const Phreeqc *pSrc)
 	max_line				= MAX_LINE;
 	line                    = NULL;
 	line_save				= NULL;
-	LOG_10                  = log(10.0);
+	LOG_10                  = LOG_10;
 	debug_model             = FALSE;
 	debug_prep              = FALSE;
 	debug_set               = FALSE;
