@@ -59,7 +59,11 @@ cxxSolutionIsotope::dump_xml(std::ostream & s_oss, unsigned int indent) const
 	s_oss << indent1;
 	s_oss << "iso_ratio=\"" << this->ratio << "\"" << "\n";
 
+#ifdef NPP
+	if (!isnan(this->ratio_uncertainty))
+#else
 	if (this->ratio_uncertainty != NAN)
+#endif
 	{
 		s_oss << indent1;
 		s_oss << "iso_ratio_uncertainty=\"" << this->
